# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.0
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

package Mac::Launcher;
use base qw(Exporter);
use base qw(DynaLoader);
package Mac::Launcherc;
bootstrap Mac::Launcher;
package Mac::Launcher;
@EXPORT = qw();

=head1 NAME

Mac::Launcher - Launch files and URL's with default Mac application.

=head1 VERSION

Version 0.03

=cut

our $VERSION = '0.04';


=head1 SYNOPSIS

This module allows you to launch a URL or a file on the Mac using the system's default application for that URL or file type. It provides similar functionality to the "/usr/bin/open" command-line tool, but works without shelling out to an external program. 

    use Mac::Launcher;

    Mac::Launcher::launchurl "http://www.apple.com";
    Mac::Launcher::launchfile "/Users/myname/Desktop/test.txt";

=head1 AUTHOR

Kevin Walzer, C<< <kw at codebykevin.com> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-mac-launcher at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Mac-Launcher>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Mac::Launcher


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Mac-Launcher>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Mac-Launcher>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Mac-Launcher>

=item * Search CPAN

L<http://search.cpan.org/dist/Mac-Launcher/>

=back


=head1 ACKNOWLEDGEMENTS

Prepared with the assistance of the Simplified Wrapper and Interface Generator, http://www.swig.org.

=head1 LICENSE AND COPYRIGHT

Copyright 2014 Kevin Walzer.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.


=cut

# ---------- BASE METHODS -------------

package Mac::Launcher;

sub TIEHASH {
    my ($classname,$obj) = @_;
    return bless $obj, $classname;
}

sub CLEAR { }

sub FIRSTKEY { }

sub NEXTKEY { }

sub FETCH {
    my ($self,$field) = @_;
    my $member_func = "swig_${field}_get";
    $self->$member_func();
}

sub STORE {
    my ($self,$field,$newval) = @_;
    my $member_func = "swig_${field}_set";
    $self->$member_func($newval);
}

sub this {
    my $ptr = shift;
    return tied(%$ptr);
}


# ------- FUNCTION WRAPPERS --------

package Mac::Launcher;

*launchurl = *Mac::Launcherc::launchurl;
*launchfile = *Mac::Launcherc::launchfile;

# ------- VARIABLE STUBS --------

package Mac::Launcher;

1;
